powered by
tidy
tidy applied on a supported model fit creates a rulelist. See Also section links to documentation of specific methods.
tidy(x, ...)
A supported model object
For model specific implementations to use
rulelist, tidy, augment, predict, calculate, prune, reorder
Other Core Tidy Utility: tidy.C5.0(), tidy.cubist(), tidy.rpart()
tidy.C5.0()
tidy.cubist()
tidy.rpart()